@@ -26,8 +26,8 @@ static void sigdel16read_16bit(t_sigdel16read *x, t_float f);
 static void *sigdel16read_new(t_symbol *s, t_floatarg f){
   t_sigdel16read *x = (t_sigdel16read *)pd_new(sigdel16read_class);
   x->x_sym = s;
-  x->x_sr = 1;
-  x->x_n = 1;
+  x->x_sr = sys_getsr();
+  x->x_n = sys_getblksize();
   x->x_zerodel = 0;
   sigdel16read_16bit(x, f);
   outlet_new(&x->x_obj, gensym("signal"));
@@ -38,13 +38,14 @@ static void sigdel16read_16bit(t_sigdel16read *x, t_float f){
   t_sigdel16write *delwriter =
     (t_sigdel16write *)pd_findbyclass(x->x_sym, sigdel16write_class);
   x->x_deltime = f;
-  if (delwriter)    {
-    x->x_delsamps = (int)(0.5 + x->x_sr * x->x_deltime)
-      + x->x_n - x->x_zerodel;
-    if (x->x_delsamps < x->x_n) x->x_delsamps = x->x_n;
-    else if (x->x_delsamps > delwriter->x_cspace.c_n - DEFDELVS)
-      x->x_delsamps = delwriter->x_cspace.c_n - DEFDELVS;
-  }
+  if (!delwriter)
+	  return;
+
+  x->x_delsamps = (int)(0.5 + x->x_sr * x->x_deltime)
+    + x->x_n - x->x_zerodel;
+  if (x->x_delsamps < x->x_n) x->x_delsamps = x->x_n;
+  else if (x->x_delsamps > delwriter->x_cspace.c_n - x->x_n)
+    x->x_delsamps = delwriter->x_cspace.c_n - x->x_n;
 }
 
 static t_int *sigdel16read_perform(t_int *w){
@@ -78,7 +79,7 @@ static void sigdel16read_dsp(t_sigdel16read *x, t_signal **sp){
             sp[0]->s_vec, &delwriter->x_cspace, &x->x_delsamps, sp[0]->s_n);
   }
   else if (*x->x_sym->s_name)
-    error("delread~: %s: no such del16write~",x->x_sym->s_name);
+    pd_error(x, "delread~: %s: no such del16write~",x->x_sym->s_name);
 }
 
 static void sigdel16read_setup(void){
