@@ -14,7 +14,7 @@
 /* ------------------------- table16 -------------------------- */
 /* a 16bit table */
 
-t_class *table16_class;
+IEM16_EXTERN t_class *table16_class;
 typedef struct _table16 {
   t_object x_obj;
 
@@ -27,8 +27,8 @@ typedef struct _table16 {
 } t_table16;
 
 
-int table16_getarray16(t_table16*x, int*size,t_iem16_16bit**vec);
-void table16_usedindsp(t_table16*x);
+IEM16_EXTERN int table16_getarray16(t_table16*x, int*size,t_iem16_16bit**vec);
+IEM16_EXTERN void table16_usedindsp(t_table16*x);
 
 
 
