@@ -23,9 +23,9 @@ static void tab16read_float(t_tab16read *x, t_float f){
   t_iem16_16bit *vec;
 
   if (!(a = (t_table16 *)pd_findbyclass(x->x_arrayname, table16_class)))
-    error("%s: no such table16", x->x_arrayname->s_name);
+    pd_error(x, "%s: no such table16", x->x_arrayname->s_name);
   else if (!table16_getarray16(a, &npoints, &vec))
-    error("%s: bad template for tab16read", x->x_arrayname->s_name);
+    pd_error(x, "%s: bad template for tab16read", x->x_arrayname->s_name);
   else    {
     int n = f;
     if (n < 0) n = 0;
