@@ -23,9 +23,9 @@ static void tab16read4_float(t_tab16read4 *x, t_float f){
   t_iem16_16bit *vec;
 
   if (!(array = (t_table16 *)pd_findbyclass(x->x_arrayname, table16_class)))
-    error("%s: no such table16", x->x_arrayname->s_name);
+    pd_error(x, "%s: no such table16", x->x_arrayname->s_name);
   else if (!table16_getarray16(array, &npoints, &vec))
-    error("%s: bad template for tab16read4", x->x_arrayname->s_name);
+    pd_error(x, "%s: bad template for tab16read4", x->x_arrayname->s_name);
   else if (npoints < 4)
     outlet_float(x->x_obj.ob_outlet, 0);
   else if (f <= 1)
