@@ -61,11 +61,11 @@ void tab16read_tilde_set(t_tab16read_tilde *x, t_symbol *s){
   x->x_arrayname = s;
   if (!(a = (t_table16 *)pd_findbyclass(x->x_arrayname, table16_class)))  {
     if (*s->s_name)
-      error("tab16read~: %s: no such table16", x->x_arrayname->s_name);
+      pd_error(x, "tab16read~: %s: no such table16", x->x_arrayname->s_name);
     x->x_vec = 0;
   }
   else if (!table16_getarray16(a, &x->x_npoints, &x->x_vec)) {
-    error("%s: bad template for tab16read~", x->x_arrayname->s_name);
+    pd_error(x, "%s: bad template for tab16read~", x->x_arrayname->s_name);
     x->x_vec = 0;
   }
   else table16_usedindsp(a);
