@@ -34,10 +34,10 @@ static void tab16receive_dsp(t_tab16receive *x, t_signal **sp){
 
   if (!(a = (t_table16 *)pd_findbyclass(x->x_arrayname, table16_class))) {
     if (*x->x_arrayname->s_name)
-      error("tab16send~: %s: no such table16", x->x_arrayname->s_name);
+      pd_error(x, "tab16send~: %s: no such table16", x->x_arrayname->s_name);
   }
   else if (!table16_getarray16(a, &vecsize, &x->x_vec))
-    error("%s: bad template for tab16receive~", x->x_arrayname->s_name);
+    pd_error(x, "%s: bad template for tab16receive~", x->x_arrayname->s_name);
   else     {
     int n = sp[0]->s_n;
     if (n < vecsize) vecsize = n;
