@@ -25,9 +25,9 @@ static void tab16write_float(t_tab16write *x, t_float f) {
   t_iem16_16bit *vec;
 
   if (!(a = (t_table16 *)pd_findbyclass(x->x_arrayname, table16_class)))
-    error("%s: no such table16", x->x_arrayname->s_name);
+    pd_error(x, "%s: no such table16", x->x_arrayname->s_name);
   else if (!table16_getarray16(a, &vecsize, &vec))
-    error("%s: bad template for tab16write", x->x_arrayname->s_name);
+    pd_error(x, "%s: bad template for tab16write", x->x_arrayname->s_name);
   else    {
     int n = x->x_ft1;
     if (n < 0) n = 0;
