@@ -57,7 +57,7 @@ void tab16write_tilde_set(t_tab16write_tilde *x, t_symbol *s){
     x->x_vec = 0;
   }
   else if (!table16_getarray16(a, &x->x_nsampsintab, &x->x_vec))    {
-    error("%s: bad template for tab16write~", x->x_arrayname->s_name);
+    pd_error(x, "%s: bad template for tab16write~", x->x_arrayname->s_name);
     x->x_vec = 0;
   }
   else table16_usedindsp(a);
