@@ -79,7 +79,7 @@ static void sig16vd_dsp(t_sig16vd *x, t_signal **sp){
             sp[0]->s_vec, sp[1]->s_vec,
             &delwriter->x_cspace, x, sp[0]->s_n);
   }
-  else error("vd~: %s: no such del16write~",x->x_sym->s_name);
+  else pd_error(x, "vd~: %s: no such del16write~",x->x_sym->s_name);
 }
 
 static void sig16vd_setup(void){
