@@ -9,6 +9,7 @@ noisternig_AT_iem.at; musil_AT_iem.at
 
 #include "m_pd.h"
 #include "iemlib.h"
+#include "iemarray.h"
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
@@ -30,12 +31,12 @@ typedef struct FXNLMSplus2in_tilde
 {
     t_object            x_obj;// common pd object structure
     t_symbol            *x_w_array_sym_name;
-    t_float             *x_w_array_mem_beg;
+    t_word              *x_w_array_mem_beg;
     t_float             *x_ref_filt_in_hist;// history buffer for input signal reference for internal convolution = filter
     t_float             *x_ref_adapt_in_hist;// history buffer for input signal reference for internal adapting filter
-    t_int               x_rw_index;// current read-write-index in circular buffer
-    t_int               x_n_order;// order of filter or convolution
-    t_int               x_update;// binary update parameter ON / OFF
+    int                 x_rw_index;// current read-write-index in circular buffer
+    int                 x_n_order;// order of filter or convolution
+    int                 x_update;// binary update parameter ON / OFF
     t_float             x_alpha;// leakage Parameter = decrease factor of w_array
     t_float             x_beta;// learn rate [0 .. 2]
     t_float             x_gamma;// regularization Parameter = minimum
@@ -44,33 +45,6 @@ typedef struct FXNLMSplus2in_tilde
 
 t_class *FXNLMSplus2in_tilde_class;
 
-static t_float *FXNLMSplus2in_tilde_check_array(t_symbol *array_sym_name, t_int length)
-{
-  int n_points;
-  t_garray *a;
-  t_float *vec;
-
-  if(!(a = (t_garray *)pd_findbyclass(array_sym_name, garray_class)))
-  {
-    error("%s: no such array for FXNLMSplus2in~", array_sym_name->s_name);
-    return((t_float *)0);
-  }
-  else if(!garray_getfloatarray(a, &n_points, &vec))
-  {
-    error("%s: bad template for FXNLMSplus2in~", array_sym_name->s_name);
-    return((t_float *)0);
-  }
-  else if(n_points < length)
-  {
-    error("%s: bad array-size for FXNLMSplus2in~: %d", array_sym_name->s_name, n_points);
-    return((t_float *)0);
-  }
-  else
-  {
-    return(vec);
-  }
-}
-
 static void FXNLMSplus2in_tilde_alpha(t_FXNLMSplus2in_tilde *x, t_floatarg f) // leakage
 {
   if(f < 0.0f)
@@ -104,7 +78,7 @@ static void FXNLMSplus2in_tilde_gamma(t_FXNLMSplus2in_tilde *x, t_floatarg f) //
 
 static void FXNLMSplus2in_tilde_update(t_FXNLMSplus2in_tilde *x, t_floatarg f) // downsample learn-rate
 {
-  t_int u = (t_int)f;
+  int u = (int)f;
 
   if((u > 2) || (u < 0)) // u==0...no update, u==1...normal update, u==2...wrong update
     u = 0;
@@ -115,10 +89,8 @@ static void FXNLMSplus2in_tilde_update(t_FXNLMSplus2in_tilde *x, t_floatarg f) /
 
 static t_int *FXNLMSplus2in_tilde_perform_zero(t_int *w)
 {
-  t_FXNLMSplus2in_tilde *x = (t_FXNLMSplus2in_tilde *)(w[5]);
-  t_int n = (t_int)(w[6]);
-  t_float *filt_out = (t_float *)(w[4]);
-  t_int i;
+  t_int n = (t_int)(w[6]), i;
+  t_sample *filt_out = (t_sample *)(w[4]);
 
   for(i=0; i<n; i++)
   {
@@ -129,20 +101,20 @@ static t_int *FXNLMSplus2in_tilde_perform_zero(t_int *w)
 
 static t_int *FXNLMSplus2in_tilde_perform(t_int *w)
 {
-  t_int n = (t_int)(w[6]);
+  t_int n = (t_int)(w[6]), i;
   t_FXNLMSplus2in_tilde *x = (t_FXNLMSplus2in_tilde *)(w[5]);
-  t_float *filt_out = (t_float *)(w[4]);// first sig out
-  t_float *err_in = (t_float *)(w[3]);// third sig in
-  t_float *ref_adapt_in = (t_float *)(w[2]);// second sig in
-  t_float *ref_filt_in = (t_float *)(w[1]);// first sig in
-  t_int n_order = x->x_n_order;   /* number of filter-order */
-  t_int rw_index = x->x_rw_index;  /* current read write index in circular buffer */
-  t_int update = x->x_update;
+  t_sample *filt_out = (t_sample *)(w[4]);// first sig out
+  t_sample *err_in = (t_sample *)(w[3]);// third sig in
+  t_sample *ref_adapt_in = (t_sample *)(w[2]);// second sig in
+  t_sample *ref_filt_in = (t_sample *)(w[1]);// first sig in
+  int n_order = x->x_n_order;   /* number of filter-order */
+  int rw_index = x->x_rw_index;  /* current read write index in circular buffer */
+  int update = x->x_update;
   t_float alpha = x->x_alpha;  /* leakage */
   t_float beta = x->x_beta;  /* learn rate */
   t_float gammax = x->x_gamma;  /* minimum energy */
   t_float my, my_err, sum, errin;
-  t_int i, j, k;
+  int j, k;
 
   if(!x->x_w_array_mem_beg)
     goto FXNLMSplus2in_tildeperfzero;// this is quick&dirty Musil/Miller style
@@ -158,7 +130,7 @@ static t_int *FXNLMSplus2in_tilde_perform(t_int *w)
     k = rw_index;
     for(j=0; j<n_order; j++)
     {
-      sum += x->x_w_array_mem_beg[j] * x->x_ref_filt_in_hist[k];
+      sum += iemarray_getfloat(x->x_w_array_mem_beg, j) * x->x_ref_filt_in_hist[k];
       k--;
       if(k < 0)
         k = n_order - 1;
@@ -198,8 +170,7 @@ static t_int *FXNLMSplus2in_tilde_perform(t_int *w)
       k = rw_index;
       for(j=0; j<n_order; j++) // without unroll
       {
-        x->x_w_array_mem_beg[j] *= alpha; // leakage
-        x->x_w_array_mem_beg[j] += x->x_ref_adapt_in_hist[k] * my_err;
+        iemarray_setfloat(x->x_w_array_mem_beg, j, alpha * iemarray_getfloat(x->x_w_array_mem_beg, j) + x->x_ref_adapt_in_hist[k] * my_err); // leakage
         k--;
         if(k < 0)
           k = n_order - 1;
@@ -223,7 +194,7 @@ FXNLMSplus2in_tildeperfzero:
 
 static void FXNLMSplus2in_tilde_dsp(t_FXNLMSplus2in_tilde *x, t_signal **sp)
 {
-    x->x_w_array_mem_beg = FXNLMSplus2in_tilde_check_array(x->x_w_array_sym_name, x->x_n_order);
+    x->x_w_array_mem_beg = iemarray_check(x, "FXNLMSplus2in~", x->x_w_array_sym_name, x->x_n_order);
 
     if(!x->x_w_array_mem_beg)
         dsp_add(FXNLMSplus2in_tilde_perform_zero, 6, sp[0]->s_vec, sp[1]->s_vec, sp[2]->s_vec, sp[3]->s_vec, x, sp[0]->s_n);
@@ -240,10 +211,10 @@ static void FXNLMSplus2in_tilde_free(t_FXNLMSplus2in_tilde *x)
     freebytes(x->x_ref_adapt_in_hist, x->x_n_order*sizeof(t_float));
 }
 
-static void *FXNLMSplus2in_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
+static void *FXNLMSplus2in_tilde_new(t_symbol *s, int argc, t_atom *argv)
 {
     t_FXNLMSplus2in_tilde *x = (t_FXNLMSplus2in_tilde *)pd_new(FXNLMSplus2in_tilde_class);
-    t_int i, n_order=39;
+    int n_order=39;
     t_symbol    *w_name;
     t_float alpha=0.999f;
     t_float beta=0.01f;
@@ -256,7 +227,7 @@ static void *FXNLMSplus2in_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
         IS_A_FLOAT(argv,3) &&
         IS_A_SYMBOL(argv,4))
     {
-        n_order = (t_int)atom_getintarg(0, argc, argv);
+        n_order = (int)atom_getfloatarg(0, argc, argv);
         alpha   = (t_float)atom_getfloatarg(1, argc, argv);
         beta    = (t_float)atom_getfloatarg(2, argc, argv);
         gammax  = (t_float)atom_getfloatarg(3, argc, argv);
@@ -298,7 +269,7 @@ static void *FXNLMSplus2in_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
 
         // table-symbols will be linked to their memory in future (dsp_routine)
         x->x_w_array_sym_name = gensym(w_name->s_name);
-        x->x_w_array_mem_beg = (t_float *)0;
+        x->x_w_array_mem_beg = (t_word *)0;
 
         x->x_rw_index = 0;
 
@@ -306,8 +277,8 @@ static void *FXNLMSplus2in_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
     }
     else
     {
-        post("FXNLMSplus2in~-ERROR: need 4 float- + 1 symbol-arguments:");
-        post("  order_of_filter + leakage + learnrate + security_value + array_name_taps");
+        pd_error(0, "%s: need 4 float- + 1 symbol-arguments:", s->s_name);
+        pd_error(0, "  order_of_filter + leakage + learnrate + security_value + array_name_taps");
         return(0);
     }
 }
