@@ -9,6 +9,7 @@ noisternig_AT_iem.at; musil_AT_iem.at
 
 #include "m_pd.h"
 #include "iemlib.h"
+#include "iemarray.h"
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
@@ -29,12 +30,12 @@ typedef struct NLMS_tilde
 {
     t_object            x_obj;
     t_symbol            *x_w_array_sym_name;
-    t_float             *x_w_array_mem_beg;
+    iemarray_t          *x_w_array_mem_beg;
     t_float             *x_io_ptr_beg[4];// memory: 2 sig-in and 2 sig-out vectors
     t_float             *x_in_hist;// start point double buffer for sig-in history
-    t_int               x_rw_index;// read-write-index
-    t_int               x_n_order;// order of filter
-    t_int               x_update;// 2^n rounded value, downsampling of update speed
+    int                 x_rw_index;// read-write-index
+    int                 x_n_order;// order of filter
+    int                 x_update;// 2^n rounded value, downsampling of update speed
     t_float             x_beta;// learn rate [0 .. 2]
     t_float             x_gamma;// regularization
     t_float             x_msi;
@@ -42,33 +43,6 @@ typedef struct NLMS_tilde
 
 t_class *NLMS_tilde_class;
 
-static t_float *NLMS_tilde_check_array(t_symbol *array_sym_name, t_int length)
-{
-    int n_points;
-    t_garray *a;
-    t_float *vec;
-
-    if(!(a = (t_garray *)pd_findbyclass(array_sym_name, garray_class)))
-    {
-        error("%s: no such array for NLMS~", array_sym_name->s_name);
-        return((t_float *)0);
-    }
-    else if(!garray_getfloatarray(a, &n_points, &vec))
-    {
-        error("%s: bad template for NLMS~", array_sym_name->s_name);
-        return((t_float *)0);
-    }
-    else if(n_points < length)
-    {
-        error("%s: bad array-size for NLMS~: %d", array_sym_name->s_name, n_points);
-        return((t_float *)0);
-    }
-    else
-    {
-        return(vec);
-    }
-}
-
 static void NLMS_tilde_beta(t_NLMS_tilde *x, t_floatarg f) // learn rate
 {
     if(f < 0.0f)
@@ -92,7 +66,7 @@ static void NLMS_tilde_gamma(t_NLMS_tilde *x, t_floatarg f) // regularization fa
 
 static void NLMS_tilde_update(t_NLMS_tilde *x, t_floatarg f) // downsample learn-rate
 {
-    t_int i=1, u = (t_int)f;
+    int i=1, u = (int)f;
 
     if(u < 0)
         u = 0;
@@ -111,11 +85,11 @@ static void NLMS_tilde_update(t_NLMS_tilde *x, t_floatarg f) // downsample learn
 static t_int *NLMS_tilde_perform_zero(t_int *w)
 {
     t_NLMS_tilde *x = (t_NLMS_tilde *)(w[1]);
-    t_int n = (t_int)(w[2]);
+    t_int n = (t_int)(w[2]), i;
 
     t_float **io = x->x_io_ptr_beg;
-    t_float *out;
-    t_int i, j;
+    t_sample *out;
+    int j;
 
     for(j=0; j<2; j++)/* output-vector-row */
     {
@@ -131,24 +105,24 @@ static t_int *NLMS_tilde_perform_zero(t_int *w)
 static t_int *NLMS_tilde_perform(t_int *w)
 {
     t_NLMS_tilde *x = (t_NLMS_tilde *)(w[1]);
-    t_int n = (t_int)(w[2]);
-    t_int n_order = x->x_n_order;   /* number of filter-order */
-    t_int rw_index = x->x_rw_index;
-    t_float *in = x->x_io_ptr_beg[0];// first sig in
-    t_float *desired_in = x->x_io_ptr_beg[1], din;// second sig in
-    t_float *filt_out = x->x_io_ptr_beg[2];// first sig out
-    t_float *err_out = x->x_io_ptr_beg[3], eout;// second sig out
+    t_int n = (t_int)(w[2]), i;
+    int n_order = x->x_n_order;   /* number of filter-order */
+    int rw_index = x->x_rw_index;
+    t_sample *in = x->x_io_ptr_beg[0];// first sig in
+    t_sample *desired_in = x->x_io_ptr_beg[1], din;// second sig in
+    t_sample *filt_out = x->x_io_ptr_beg[2];// first sig out
+    t_sample *err_out = x->x_io_ptr_beg[3], eout;// second sig out
     t_float *write_in_hist1 = x->x_in_hist;
     t_float *write_in_hist2 = write_in_hist1+n_order;
     t_float *read_in_hist = write_in_hist2;
-    t_float *w_filt_coeff = x->x_w_array_mem_beg;
+    iemarray_t *w_filt_coeff = x->x_w_array_mem_beg;
     t_float my, my_err, sum;
     t_float beta = x->x_beta;
     t_float gammax = x->x_gamma;
-    t_int i, j, update_counter;
-    t_int update = x->x_update;
-    t_int ord8=n_order&0xfffffff8;
-    t_int ord_residual=n_order&0x7;
+    int j, update_counter;
+    int update = x->x_update;
+    int ord8=n_order&0xfffffff8;
+    int ord_residual=n_order&0x7;
 
     if(!w_filt_coeff)
         goto NLMS_tildeperfzero;// this is quick&dirty Musil/Miller style
@@ -165,19 +139,22 @@ static t_int *NLMS_tilde_perform(t_int *w)
         read_in_hist = &write_in_hist2[rw_index];
         for(j=0; j<ord8; j+=8)  // loop unroll 8 taps
         {
-            sum += w_filt_coeff[0] * read_in_hist[0];
-            sum += w_filt_coeff[1] * read_in_hist[-1];
-            sum += w_filt_coeff[2] * read_in_hist[-2];
-            sum += w_filt_coeff[3] * read_in_hist[-3];
-            sum += w_filt_coeff[4] * read_in_hist[-4];
-            sum += w_filt_coeff[5] * read_in_hist[-5];
-            sum += w_filt_coeff[6] * read_in_hist[-6];
-            sum += w_filt_coeff[7] * read_in_hist[-7];
+#define update_sum_with_hist(idx) \
+    sum += iemarray_getfloat(w_filt_coeff, idx) * read_in_hist[-idx]
+
+            update_sum_with_hist(0);
+            update_sum_with_hist(1);
+            update_sum_with_hist(2);
+            update_sum_with_hist(3);
+            update_sum_with_hist(4);
+            update_sum_with_hist(5);
+            update_sum_with_hist(6);
+            update_sum_with_hist(7);
             w_filt_coeff += 8;
             read_in_hist -= 8;
         }
         for(j=0; j<ord_residual; j++)   // for filter order < 2^N
-            sum += w_filt_coeff[j] * read_in_hist[-j];
+        update_sum_with_hist(j);
 
         filt_out[i] = sum;
         eout = din - filt_out[i];       // buffer-struct for further use
@@ -194,18 +171,21 @@ static t_int *NLMS_tilde_perform(t_int *w)
                 read_in_hist = &write_in_hist2[rw_index];
                 for(j=0; j<ord8; j+=8)  // unrolling quadrature calc
                 {
-                    sum += read_in_hist[0] * read_in_hist[0];
-                    sum += read_in_hist[-1] * read_in_hist[-1];
-                    sum += read_in_hist[-2] * read_in_hist[-2];
-                    sum += read_in_hist[-3] * read_in_hist[-3];
-                    sum += read_in_hist[-4] * read_in_hist[-4];
-                    sum += read_in_hist[-5] * read_in_hist[-5];
-                    sum += read_in_hist[-6] * read_in_hist[-6];
-                    sum += read_in_hist[-7] * read_in_hist[-7];
+#define update_sum_square(idx) \
+          sum += read_in_hist[-idx] * read_in_hist[-idx]
+
+                    update_sum_square(0);
+                    update_sum_square(1);
+                    update_sum_square(2);
+                    update_sum_square(3);
+                    update_sum_square(4);
+                    update_sum_square(5);
+                    update_sum_square(6);
+                    update_sum_square(7);
                     read_in_hist -= 8;
                 }
                 for(j=0; j<ord_residual; j++)   // residual
-                    sum += read_in_hist[-j] * read_in_hist[-j]; // [-j] only valid for Musil's double buffer structure
+                    update_sum_square(j); //[-j] only valid for Musil's double buffer structure
                 sum += gammax * gammax * (float)n_order; // convert gammax corresponding to filter order
                 my = beta / sum;// calculate mue
 
@@ -214,7 +194,7 @@ static t_int *NLMS_tilde_perform(t_int *w)
                 w_filt_coeff = x->x_w_array_mem_beg; // coefficient constraints
                 read_in_hist = &write_in_hist2[rw_index];
                 for(j=0; j<n_order; j++) // without unroll
-                    w_filt_coeff[j] += read_in_hist[-j] * my_err;
+                    iemarray_iadd(w_filt_coeff, j, read_in_hist[-j] * my_err);
             }
         }
         rw_index++;
@@ -238,12 +218,13 @@ NLMS_tildeperfzero:
 
 static void NLMS_tilde_dsp(t_NLMS_tilde *x, t_signal **sp)
 {
-    t_int i, n = sp[0]->s_n;
+    t_int n = sp[0]->s_n;
+    int i;
 
     for(i=0; i<4; i++) // store io_vec
         x->x_io_ptr_beg[i] = sp[i]->s_vec;
 
-    x->x_w_array_mem_beg = NLMS_tilde_check_array(x->x_w_array_sym_name, x->x_n_order);
+    x->x_w_array_mem_beg = iemarray_check(x, "NLMS~", x->x_w_array_sym_name, x->x_n_order);
 
     if(!x->x_w_array_mem_beg)
         dsp_add(NLMS_tilde_perform_zero, 2, x, n);
@@ -259,10 +240,10 @@ static void NLMS_tilde_free(t_NLMS_tilde *x)
     freebytes(x->x_in_hist, 2*x->x_n_order*sizeof(t_float));
 }
 
-static void *NLMS_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
+static void *NLMS_tilde_new(t_symbol *s, int argc, t_atom *argv)
 {
     t_NLMS_tilde *x = (t_NLMS_tilde *)pd_new(NLMS_tilde_class);
-    t_int i, n_order=39;
+    int n_order=39;
     t_symbol    *w_name;
     t_float beta=0.1f;
     t_float gammax=0.00001f;
@@ -273,7 +254,7 @@ static void *NLMS_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
         IS_A_FLOAT(argv,2) &&
         IS_A_SYMBOL(argv,3))
     {
-        n_order = (t_int)atom_getintarg(0, argc, argv);
+        n_order = (int)atom_getfloatarg(0, argc, argv);
         beta    = (t_float)atom_getfloatarg(1, argc, argv);
         gammax  = (t_float)atom_getfloatarg(2, argc, argv);
         w_name  = (t_symbol *)atom_getsymbolarg(3, argc, argv);
@@ -307,14 +288,14 @@ static void *NLMS_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
 
         // table-symbols will be linked to their memory in future (dsp_routine)
         x->x_w_array_sym_name = gensym(w_name->s_name);
-        x->x_w_array_mem_beg = (t_float *)0;
+        x->x_w_array_mem_beg = (iemarray_t *)0;
 
         return(x);
     }
     else
     {
-        post("NLMS~-ERROR: need 3 float- + 1 symbol-arguments:");
-        post("  order_of_filter + learnrate_beta + security_value + array_name_taps");
+        pd_error(0, "%s: need 3 float- + 1 symbol-arguments:", s->s_name);
+        pd_error(0, "  order_of_filter + learnrate_beta + security_value + array_name_taps");
         return(0);
     }
 }
