@@ -99,7 +99,7 @@ static t_int *delwrite_tilde_tilde_perform(t_int *w)
     while (n--)
     {
         t_sample f = *in++;
-        if(IEM_DENORMAL(f))
+        if(IEM_DENORMAL_T(f))
             f = 0;
         *bp++ = f;
         if (bp == ep)
@@ -273,7 +273,7 @@ static void delread_tilde_tilde_dsp(t_delread_tilde_tilde *x, t_signal **sp)
             sp[0]->s_vec, &delwriter->x_cspace, &x->x_delsamps, sp[0]->s_n);
   }
   else if (*x->x_sym->s_name)
-    error("delread~~: %s: no such delwrite~~",x->x_sym->s_name);
+    pd_error(x, "delread~~: %s: no such delwrite~~",x->x_sym->s_name);
 }
 
 static void delread_tilde_tilde_setup(void)
@@ -369,7 +369,7 @@ static void vd_tilde_tilde_dsp(t_vd_tilde_tilde *x, t_signal **sp)
       &delwriter->x_cspace, x, sp[0]->s_n);
   }
   else
-    error("vd~~: %s: no such delwrite~~", x->x_sym->s_name);
+    pd_error(x, "vd~~: %s: no such delwrite~~", x->x_sym->s_name);
 }
 
 static void vd_tilde_tilde_setup(void)
