@@ -32,7 +32,7 @@ typedef struct _dptohex
 static void dptohex_bang(t_dptohex *x)
 {
   char buf[100];
-  union tabfudge_d tf;
+  union tabfudge tf;
 
   tf.tf_d = iem_dp_calc_sum(x->x_float_casted_value, x->x_residual);
   sprintf(buf, "#%08X%08X", tf.tf_i[HIOFFSET], tf.tf_i[LOWOFFSET]);
