@@ -24,6 +24,13 @@ typedef struct _ftohex
   t_object  x_obj;
 } t_ftohex;
 
+union tabfudge_f
+{
+    float tf_f;
+    long tf_l;
+};
+
+
 static void ftohex_float(t_ftohex *x, t_floatarg f)
 {
   char buf[100];
