@@ -40,7 +40,7 @@ typedef struct _scalarmin_tilde_tilde
 
 static void *min_tilde_tilde_new(t_symbol *s, int argc, t_atom *argv)
 {
-  if(((argc==1)&&(argv->a_type == A_FLOAT))||(argc>=2)&&(argv->a_type == A_FLOAT)&&((argv+1)->a_type == A_FLOAT))
+  if(((argc==1)&&(argv->a_type == A_FLOAT))||((argc>=2)&&(argv->a_type == A_FLOAT)&&((argv+1)->a_type == A_FLOAT)))
   {
     t_scalarmin_tilde_tilde *x = (t_scalarmin_tilde_tilde *)pd_new(scalarmin_tilde_tilde_class);
 
