@@ -80,10 +80,10 @@ static void spec2_tab_conv_tilde_dsp(t_spec2_tab_conv_tilde *x, t_signal **sp)
     if(!(a = (t_garray *)pd_findbyclass(x->x_sym_array, garray_class)))
     {
       if(*x->x_sym_array->s_name)
-        error("spec2_tab_conv~: %s: no such array", x->x_sym_array->s_name);
+        pd_error(x, "spec2_tab_conv~: %s: no such array", x->x_sym_array->s_name);
     }
     else if(!iemarray_getarray(a, &n_points, &x->x_beg_array))
-      error("%s: bad template for spec2_tab_conv~", x->x_sym_array->s_name);
+      pd_error(x, "%s: bad template for spec2_tab_conv~", x->x_sym_array->s_name);
     else 
     {
       if(n_points > (n+1))
