@@ -125,10 +125,10 @@ static void spec2_tabreceive_enable_tilde_dsp(t_spec2_tabreceive_enable_tilde *x
   if(!(a = (t_garray *)pd_findbyclass(x->x_arrayname, garray_class)))
   {
     if(*x->x_arrayname->s_name)
-      error("spec2_tabreceive_enable~: %s: no such array", x->x_arrayname->s_name);
+      pd_error(x, "spec2_tabreceive_enable~: %s: no such array", x->x_arrayname->s_name);
   }
   else if(!iemarray_getarray(a, &vecsize, &x->x_vec))
-    error("%s: bad template for spec2_tabreceive_enable~", x->x_arrayname->s_name);
+    pd_error(x, "%s: bad template for spec2_tabreceive_enable~", x->x_arrayname->s_name);
   else 
   {
     int n = sp[0]->s_n;
