@@ -695,7 +695,7 @@ static void canvas_patcherize(t_glist*cnv, t_symbol*s) {
 void patcherize_setup(void)
 {
   if(NULL==canvas_class) {
-    verbose(10, "patcherize detected class_new() @ %p", class_new);
+    logpost(0, PD_VERBOSE, "patcherize detected class_new() @ %p", class_new);
     return;
   }
   //iemguts_boilerplate("patcherize - turn objects into a subpatch", 0);
