@@ -453,11 +453,11 @@ void triggerize_setup(void)
   int major, minor, bugfix;
   sys_getversion(&major, &minor, &bugfix);
   if((major>0 || minor >= 49)) {
-    error("triggerize built into Pd>=0.49, not enabling iem::punish::triggerize");
+    pd_error(0, "triggerize built into Pd>=0.49, not enabling iem::punish::triggerize");
     return;
   }
   if(NULL==canvas_class) {
-    verbose(10, "triggerize detected class_new() @ %p", class_new);
+    logpost(0, PD_VERBOSE, "triggerize detected class_new() @ %p", class_new);
     return;
   }
   post("triggerize - insert [trigger] ad lib.");
